@@ -9,6 +9,9 @@
 #'
 #' @param ... Other named arguments, passed to \code{\link{compute_mallows}}.
 #'
+#' @param cl Optional computing cluster used for parallelization, returned
+#' from \code{parallel::makeCluster}. Defaults to \code{NULL}.
+#'
 #' @return A list of Mallows models of class \code{BayesMallowsMixtures}, with one element
 #' for each number of mixtures that
 #' was computed. This object can be studied with \code{\link{plot_elbow}}.
@@ -18,13 +21,23 @@
 #'
 #' @example /inst/examples/compute_mallows_mixtures_example.R
 #'
-compute_mallows_mixtures <- function(n_clusters, ...){
+compute_mallows_mixtures <- function(n_clusters, ..., cl = NULL){
   stopifnot(is.numeric(n_clusters))
+  stopifnot(is.null(cl) || inherits(cl, "cluster"))
 
-  models <- purrr::map(n_clusters, function(x) {
-    message(paste0("Computing Mallows model with ", x, " clusters."))
-    compute_mallows(..., n_clusters = x)
-  })
+  if(is.null(cl)){
+    models <- purrr::map(n_clusters, function(x) {
+      compute_mallows(..., n_clusters = x)
+    })
+  } else {
+    args <- list(...)
+    parallel::clusterExport(cl = cl, varlist = "args", envir = environment())
+    models <- parallel::parLapply(cl = cl, X = n_clusters, fun = function(x){
+      args$n_clusters <- x
+      do.call(compute_mallows, args)
+    })
+
+  }
 
   class(models) <- "BayesMallowsMixtures"
   return(models)
